#ifndef NT2_INCLUDE_CONSTANTS_MHALF_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MHALF_HPP_INCLUDED

#include <nt2/constant/include/constants/mhalf.hpp>

#endif
